local addonName = ...
local addonTitle = select(2, GetAddOnInfo(addonName))
local db, dbpc

HideRetail = LibStub("AceAddon-3.0"):NewAddon(addonName, "AceConsole-3.0")

local options = { -- OptionsTable
    name = addonName,
	type = 'group',
    args = {
		intro = {
			order = 1,
			type = "description",
			name = "These settings are character specific.",
		},
		InterfaceOptions = {
			get = function(info) return dbpc.enabledoptions[ info[#info] ] end,
			set = function(info, value) dbpc.enabledoptions[ info[#info] ] = value UpdateMicroButtons() end,
			type = "group",
			order = 2,
			guiInline = true,
			name = "Blizzard Interface",
			args = {
				Gryphons = {
					type = 'toggle',
					order = 1,
					name = 'Hide Gryphons',
					width = 'full',
				},
				Alerts = {
					type = 'toggle',
					order = 2,
					name = 'Hide MicroBar Alerts',
					width = 'full',
				},
				BagBar = {
					type = 'toggle',
					order = 3,
					name = 'Hide MicroButtonAndBagsBar',
					width = 'full',
				},
				Shop = {
					type = 'toggle',
					name = 'Hide Shop',
					width = 'full',
				},
				AdventureGuide = {
					type = 'toggle',
					name = 'Hide AdventureGuide - Removes KeyBinds',
					width = 'full',
				},
				LFD = {
					type = 'toggle',
					name = 'Hide LFDungeon - Removes KeyBinds',
					width = 'full',
				},
				Achievement = {
					type = 'toggle',
					name = 'Hide Achievement - Removes KeyBinds',
					width = 'full',
				},
			},
		},
		Collections = {
			get = function(info) return dbpc.enabledoptions[ info[#info] ] end,
			set = function(info, value) dbpc.enabledoptions[ info[#info] ] = value end,
			type = "group",
			order = 2,
			guiInline = true,
			name = "Collections Interface - Requires RELOAD",
			args = {
				Heirlooms = {
					type = 'toggle',
					name = 'Hide Heirlooms - Removes KeyBinds',
					width = 'full',
				},
				Appearances = {
					type = 'toggle',
					name = 'Hide Appearances - Removes KeyBinds',
					width = 'full',
				},
				cleardata = {
					type = "execute",
					name = "RELOAD UI", -- Query Options
					func = function() ReloadUI() end,
				},
			},
		},
    },
}

------------------ Option Menu Interface
local acr = LibStub("AceConfigRegistry-3.0")
local acd = LibStub("AceConfigDialog-3.0")

function HideRetail:OnInitialize()
	--RegisterDB
    self.db = LibStub("AceDB-3.0"):New("HRDB", {
			profile = {
			},
		}, "global")
	db = self.db.profile
	self.dbpc = LibStub("AceDB-3.0"):New("HRDBPC", {
			profile = {
				enabledoptions = {
					BagBar = false,
					Gryphons = true,
					Heirlooms = false, -- Removes KeyBinds
					Appearances = false, -- Removes KeyBinds
					Shop = false,
					AdventureGuide = false, -- Removes KeyBinds
					LFD = false, -- Removes KeyBinds
					Achievement = false, -- Removes KeyBinds
					Alerts = true,
				},
		    },
		}, "global")
	dbpc = self.dbpc.profile
	
	acr:RegisterOptionsTable(addonName, options)	-- RegisterOptionsTable
	local options = acd:AddToBlizOptions(addonName, addonTitle) -- Adds Options to Interface/Addon
end


 -- Hooks into the UpdateMicroButtons
hooksecurefunc("UpdateMicroButtons",function(...)
	if dbpc.enabledoptions.BagBar then
		MicroButtonAndBagsBar:Hide()
	else MicroButtonAndBagsBar:Show() end
	
	if dbpc.enabledoptions.Shop then
		StoreMicroButton:Hide() 
	else StoreMicroButton:Show() end
	
	if dbpc.enabledoptions.AdventureGuide then
		EJMicroButton:Hide() 
	else EJMicroButton:Show() end
	
	if dbpc.enabledoptions.LFD then
		LFDMicroButton:Hide() 
	else LFDMicroButton:Show() end
	
	if dbpc.enabledoptions.Achievement then
		AchievementMicroButton:Hide() 
	else AchievementMicroButton:Show() end
	
	if dbpc.enabledoptions.Gryphons then
		MainMenuBarArtFrame.LeftEndCap:Hide() MainMenuBarArtFrame.RightEndCap:Hide()
	else
		MainMenuBarArtFrame.LeftEndCap:Show() MainMenuBarArtFrame.RightEndCap:Show()
	end
end)

-- Remove KeyBinds
function UnBind(key)
	SetBinding(key)
	SaveBindings(GetCurrentBindingSet()) -- Otherwise they will reset
end

 -- Collections Interface
local HideRetail = CreateFrame("Frame")
HideRetail:RegisterEvent("ADDON_LOADED")
HideRetail:RegisterEvent("PLAYER_LOGIN")

function filterAchievement(msg)
	return true
end

function MainMenuMicroButton_AreAlertsEnabled()
	if dbpc.enabledoptions.Heirlooms then
		return false
	end
end

HideRetail:SetScript("OnEvent", function(self, event, ...)
	-- Hides Collections
	if IsAddOnLoaded("Blizzard_Collections") then
		if dbpc.enabledoptions.Heirlooms then
			CollectionsJournalTab4:Hide()
		else CollectionsJournalTab4:Show() end
		if dbpc.enabledoptions.Appearances then
			CollectionsJournalTab5:Hide()
		else CollectionsJournalTab5:Show() end
	end
	
	-- Unbinds Keys
    if event == "PLAYER_LOGIN" then
		HideRetail:UnregisterEvent("PLAYER_LOGIN")
		
		local Unbindkeys = {}
		if dbpc.enabledoptions.Achievement then
			-- Unbind Keys
			table.insert(Unbindkeys, "TOGGLEACHIEVEMENT")
			table.insert(Unbindkeys, "TOGGLESTATISTICS")
			-- Filter Chat Announcements
			ChatFrame_AddMessageEventFilter("CHAT_MSG_GUILD_ACHIEVEMENT", filterAchievement)
			ChatFrame_AddMessageEventFilter("CHAT_MSG_ACHIEVEMENT", filterAchievement)
		end
		
		if dbpc.enabledoptions.Heirlooms then
			table.insert(Unbindkeys, "TOGGLECOLLECTIONSHEIRLOOM")
		end
		if dbpc.enabledoptions.Appearances then
			table.insert(Unbindkeys, "TOGGLECOLLECTIONSWARDROBE")
		end
		if dbpc.enabledoptions.AdventureGuide then
			table.insert(Unbindkeys, "TOGGLEENCOUNTERJOURNAL")
		end
		if dbpc.enabledoptions.LFD then
			table.insert(Unbindkeys, "TOGGLEGROUPFINDER")
			table.insert(Unbindkeys, "TOGGLEDUNGEONSANDRAIDS")
			table.insert(Unbindkeys, "TOGGLECHARACTER4")
		end
		
		for _,Unbindkey in pairs(Unbindkeys) do
			local key1, key2 = GetBindingKey(Unbindkey)
			if key1 ~= nil then UnBind(key1) end
			if key2 ~= nil then UnBind(key2) end		
		end
	end
end)
